Keen | Removed Subheader
Description: Removed subheader example

# Customer Relationship Management

New Order
New Customers
28 Daily Avr
+958
Sales Increase
92 Daily Avr
75%
Weekly Orders
122 Daily Avr
7,300
08 Dec

### AirGreat Presentation

Oxfort Street
To start a blog, think of a topic about and first brainstorm ways to write details
+3
Join
23 Dec

### Christmas Party

Bolton House
To start a blog, think of a topic about and first brainstorm party is ways to write details
+5
Join
05 Jan

### Outdoor Activity Day

South Suton
To start a blog, think of a topic about and first brainstorm party is ways to write details
+3
Join

### Top Products

HTML 5 Templates
Font-end,Admin & Email
+79%
Wordpress Themes
eCommerce Website, Plugin
+21%
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
UI/UX Design
Evrything you ever imagine
+4%
Freebie Themes
Font-end & Admin
+34
UI/UX Design
Evrything you ever imagine
+4%
HTML 5 Templates
Font-end,Admin & Email
+79%
Wordpress Themes
eCommerce Website, Plugin
+21%
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
Freebie Themes
Font-end & Admin
+34
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
UI/UX Design
Evrything you ever imagine
+4%
Latest Trends
eCommerce Website, Plugin
+34%
HTML 5 Templates
Font-end,Admin & Email
+79%
Freebie Themes
Font-end & Admin
+34

### Revenue Growth

Author
Customer

### Top Categories

Templates
Front-end, Admin
5.7k
+780
Wordpress
eCommerce, Website
2.8k
+350
eCommerce
Fashion Websites
9.3k
+2.1k
UI/UX Design
Everything you like
9.3k
+1.6k
SAAS Solution
Monthly Subscription
5.7k
+598
New Products

### Active Smartwatch

Beautifully designed watch that helps you track your fitness and diet – while keeping you motivated!
246
Purchases
37
Reviews
24 Nov, 2018
Date of Release
Preview Details

### DSLR Lens

Wide-angle, Quick Focus. Emphasis is on modern lenses for 35 mm film SLRs and for DSLRs with sensor sizes less than or equal to 35 mm.
142
Purchases
25
Reviews
24 Nov, 2018
Date of Release
Preview Details

### Polaroid Camera

Instant is back! Make photos fun again with the new range of Polaroid Instant Cameras with Vintage Effects and Built in Flash
3578
Purchases
457
Reviews
24 Nov, 2018
Date of Release
Preview Details
New Authors
Andy John
AngularJS Expert
sale@boatline.com
(+44) 345 345 4705
01 Sep, 2018
Joined Date
Message Profile
Patrick Smith
ReactJS Expert
patrick@boatline.com
(+44) 345 345 5574
01 Sep, 2018
Joined Date
Message Profile
Amanda Collin
Project Manager
amanda@boatline.com
(+44) 345 345 1247
01 Sep, 2018
Joined Date
Message Profile

### Work Progress

Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report
Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report

### Recent Orders 32500 total

Sort By:
New Record

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!